@@ -22,10 +22,9 @@ class BaseDataModel():
         """Converts a data model to a dictionary."""
         calling_classes = calling_classes or []
         ret = {}
-        for attr in self.__dict__:
+        for attr, value in self.__dict__.items():
             if attr.startswith('_') or not kwargs.get(attr, True):
                 continue
-            value = self.__dict__[attr]
 
             if recurse:
                 if isinstance(getattr(self, attr), list):
